//
//  ViewController.swift
//  Sag es!
//
//  Created by Holger Hinzberg on 09.10.17.
//  Copyright © 2017 Holger Hinzberg. All rights reserved.
//

import UIKit
import AVFoundation

class ViewController: UIViewController, AVSpeechSynthesizerDelegate,
    UIPickerViewDelegate, UIPickerViewDataSource
{
    @IBOutlet var eingabeTextField: UITextField!
    @IBOutlet var stopButton: UIButton!
    @IBOutlet var sagEsButton: UIButton!
    
    var sprachSynthesizer:AVSpeechSynthesizer?
    // Ein Array für die zur Auswahl stehenden Länder
    var laender:[Landinfo]?
    
    // Eine Eigenschaft, um die ausgewählte
    // Länderkennung anzulegen
    var gewahlteKennung:String?
    
    override func viewDidLoad()
    {
        super.viewDidLoad()
        
        self.laender = [Landinfo]()
        self.laender?.append(Landinfo(kennung: "de-de", bezeichnung: "Deutschland"))
        self.laender?.append(Landinfo(kennung: "en-gb", bezeichnung: "Großbritannien"))
        self.laender?.append(Landinfo(kennung: "en-au", bezeichnung: "Australien"))
        self.laender?.append(Landinfo(kennung: "en-us", bezeichnung: "USA"))
        self.laender?.append(Landinfo(kennung: "fr", bezeichnung: "Frankreich"))
        
        if let ersteKennung = self.laender?[0].kennung
        {
            self.gewahlteKennung = ersteKennung
        }
        
        self.stopButton.isEnabled = false
        
        self.sprachSynthesizer = AVSpeechSynthesizer()
        // Der ViewController wird zum Delegate
        // des SprachSynthesizers
        self.sprachSynthesizer?.delegate = self
    }

    override func didReceiveMemoryWarning()
    {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }
    
    @IBAction func sagEsButtonBeruehrt(_ sender: Any)
    {
        // Die Eingabe überprüfen
        guard eingabeTextField.text != "" else
        {
            return
        }
        
        let utterance = AVSpeechUtterance(string: eingabeTextField!.text!)
        utterance.voice = AVSpeechSynthesisVoice(language: self.gewahlteKennung)
        
        self.sprachSynthesizer?.speak(utterance)
        print(eingabeTextField!.text!)
        
        // Die Schaltflächen aktivieren/dekativieren
        self.sagEsButton.isEnabled = false
        self.stopButton.isEnabled = true
    }

    func speechSynthesizer(_ synthesizer: AVSpeechSynthesizer, didFinish utterance: AVSpeechUtterance)
    {
        // Die Schaltflächen aktivieren/dekativieren
        self.sagEsButton.isEnabled = true
        self.stopButton.isEnabled = false
    }
    
    @IBAction func stopButtonBeruehrt(_ sender: Any)
    {
        // Die Sprachausgabe anhalten
        self.sprachSynthesizer?.stopSpeaking(at: AVSpeechBoundary.immediate)
        // Die Schaltflächen aktivieren/dekativieren
        self.sagEsButton.isEnabled = true
        self.stopButton.isEnabled = false
    }
    
    func numberOfComponents(in pickerView: UIPickerView) -> Int
    {
        return 1
    }
    
    func pickerView(_ pickerView: UIPickerView, numberOfRowsInComponent component: Int) -> Int
    {
        return self.laender!.count
    }
    
    func pickerView(_ pickerView: UIPickerView, titleForRow row: Int, forComponent component: Int) -> String?
    {
        // Das Landinfo-Objekt an der richtigen Stelle
        // aus dem Array holen
        if let land = self.laender?[row]
        {
            // Die Bezeichung des Landes zurückgeben
            return land.bezeichnung
        }
        
        // Einen leeren String zurückgeben, wenn
        // kein Landinfo-Objekt zur
        // Verfügung steht
        return ""
    }
    
    func pickerView(_ pickerView: UIPickerView, didSelectRow row: Int, inComponent component: Int)
    {
        // Das Landinfo-Objekt an der richtigen Stelle
        // aus dem Array holen
        if let land = self.laender?[row]
        {
            // Die ausgewählte Länderkennung der Eigenschaft zuweisen
            self.gewahlteKennung = land.kennung
            print(self.gewahlteKennung!)
        }
    }
    
}

